==> jei-1.21.5-fabric-21.4.0.27-sources.jar: mezz/jei/common/gui/elements/HighResolutionDrawable.java <==
package mezz.jei.common.gui.elements;

import com.google.common.base.Preconditions;
import mezz.jei.api.gui.drawable.IDrawable;
import net.minecraft.class_332;

/**
 * Draws an icon at a higher resolution than normal (determined by the scale parameter).
 */
public class HighResolutionDrawable implements IDrawable {
	private final IDrawable drawable;
	private final int scale;

	public HighResolutionDrawable(IDrawable drawable, int scale) {
		int width = drawable.getWidth();
		int height = drawable.getHeight();
		Preconditions.checkArgument(
			width % scale == 0,
			String.format("drawable width %s must be divisible by the scale %s", width, scale)
		);
		Preconditions.checkArgument(
			height % scale == 0,
			String.format("drawable height %s must be divisible by the scale %s", height, scale)
		);

		this.drawable = drawable;
		this.scale = scale;
	}

	@Override
	public int getWidth() {
		return drawable.getWidth() / scale;
	}

	@Override
	public int getHeight() {
		return drawable.getHeight() / scale;
	}

	@Override
	public void draw(class_332 guiGraphics, int xOffset, int yOffset) {
		var poseStack = guiGraphics.method_51448();
		poseStack.method_22903();
		{
			poseStack.method_46416(xOffset, yOffset, 0);
			poseStack.method_22905(1 / (float) scale, 1 / (float) scale, 1);
			this.drawable.draw(guiGraphics);
		}
		poseStack.method_22909();
	}

	@Override
	public void draw(class_332 guiGraphics) {
		var poseStack = guiGraphics.method_51448();
		poseStack.method_22903();
		{
			poseStack.method_22905(1 / (float) scale, 1 / (float) scale, 1);
			this.drawable.draw(guiGraphics);
		}
		poseStack.method_22909();
	}
}

==> jei-1.21.10-fabric-26.2.0.28-sources.jar: mezz/jei/common/gui/elements/HighResolutionDrawable.java <==
package mezz.jei.common.gui.elements;

import com.google.common.base.Preconditions;
import mezz.jei.api.gui.drawable.IDrawable;
import net.minecraft.class_332;

/**
 * Draws an icon at a higher resolution than normal (determined by the scale parameter).
 */
public class HighResolutionDrawable implements IDrawable {
	private final IDrawable drawable;
	private final int scale;

	public HighResolutionDrawable(IDrawable drawable, int scale) {
		int width = drawable.getWidth();
		int height = drawable.getHeight();
		Preconditions.checkArgument(
			width % scale == 0,
			String.format("drawable width %s must be divisible by the scale %s", width, scale)
		);
		Preconditions.checkArgument(
			height % scale == 0,
			String.format("drawable height %s must be divisible by the scale %s", height, scale)
		);

		this.drawable = drawable;
		this.scale = scale;
	}

	@Override
	public int getWidth() {
		return drawable.getWidth() / scale;
	}

	@Override
	public int getHeight() {
		return drawable.getHeight() / scale;
	}

	@Override
	public void draw(class_332 guiGraphics, int xOffset, int yOffset) {
		var poseStack = guiGraphics.method_51448();
		poseStack.pushMatrix();
		{
			poseStack.translate(xOffset, yOffset);
			poseStack.scale(1 / (float) scale, 1 / (float) scale);
			this.drawable.draw(guiGraphics);
		}
		poseStack.popMatrix();
	}

	@Override
	public void draw(class_332 guiGraphics) {
		var poseStack = guiGraphics.method_51448();
		poseStack.pushMatrix();
		{
			poseStack.scale(1 / (float) scale, 1 / (float) scale);
			this.drawable.draw(guiGraphics);
		}
		poseStack.popMatrix();
	}
}
